@@ -26,8 +26,8 @@ from . mi_request import mi_request_programs
 
 
 class MiApi:
-    def __init__(self, ip: str, port: int, usr: str, pwd: str):
-        self.ip = ip
+    def __init__(self, host: str, port: int, usr: str, pwd: str):
+        self.host = host
         self.port = port
         self.usr = usr
         self.pwd = pwd
@@ -35,7 +35,7 @@ class MiApi:
     def execute(self, program: str, transaction: str, **kwargs) -> Union[MiRecords, MiError]:
         return mi_parse_execute(
             mi_request_execute(
-                self.ip,
+                self.host,
                 self.port,
                 self.usr,
                 self.pwd,
@@ -48,7 +48,7 @@ class MiApi:
     def program_list(self) -> Union[MiPrograms, MiError]:
         return mi_parse_programs(
             mi_request_programs(
-                self.ip,
+                self.host,
                 self.port,
                 self.usr,
                 self.pwd
@@ -58,7 +58,7 @@ class MiApi:
     def program_meta(self, program: str) -> Union[MiProgramMetadata, MiError]:
         return mi_parse_metadata(
             mi_request_metadata(
-                self.ip,
+                self.host,
                 self.port,
                 self.usr,
                 self.pwd,
@@ -72,9 +72,8 @@ class MiApi:
         if isinstance(program_meta, MiError):
             return program_meta
 
-        elif program_meta.status:
-            for record in program_meta.transactions:
-                if record.transaction == transaction:
-                    return record
+        for record in program_meta.transactions:
+            if record.transaction == transaction:
+                return record
         else:
             return None
